@@ -58,7 +58,7 @@
 #endif
 
 #if !defined(__FreeBSD__) && !defined(__linux__) && !defined(__NetBSD__) \
-	&& !defined(__OpenBSD__) && !defined(__solaris__)
+	&& !defined(__OpenBSD__) && !defined(__solaris__) &&!defined(__APPLE__)
 #define  USE_LIBGTOP
 #endif
 
@@ -108,7 +108,7 @@
 */
 #define	GKRELLM_VERSION_MAJOR	1
 #define	GKRELLM_VERSION_MINOR	2
-#define	GKRELLM_VERSION_REV		12
+#define	GKRELLM_VERSION_REV		13
 /* Backward compatibility */
 #define	VERSION_MAJOR			GKRELLM_VERSION_MAJOR
 #define	VERSION_MINOR			GKRELLM_VERSION_MINOR
@@ -942,7 +942,8 @@ struct	ThemeConfig
 	gint		theme_n_alternatives;
 	gint		theme_alternative;
 	gboolean	font_override,
-				use_fontset;
+				use_fontset,
+				no_messages;
 	gint		m2;
 	gint		use_top_bottom_margins;
 
